@@ -23,7 +23,7 @@ experimental data an labels ordered as follows:
 -------------------------------------------------------------------------------------
 """
 
-#__version__ = "0.1.0"
+#__version__ = "0.1.9"
 #__author__ = 'María M. Zanardi & Ariel M. Sarotti'
 
 import glob
@@ -90,18 +90,18 @@ def GUI():
 
 def user_guide():
     '''Open user guide documentation'''
-    
     file = (Path(__file__).parent / "UserGuide" /"UserGuide.pdf").as_posix()
     webbrowser.open_new(file)
     return
     
 def example(): 
+    '''Copy a folder with examples to the user Desktop to try the programm'''
     desktop = os.path.join(os.path.join(os.environ['USERPROFILE']), 'Desktop')
     example_fold = (Path(__file__).parent / "Example_messi_nmr").as_posix()
     shutil.copytree(example_fold, os.path.join(desktop,"Example_messi_nmr"))
     
     examp_add = tk.Tk()
-    examp_add.wm_title("DP4+")
+    examp_add.wm_title("MESSI")
     examp_add.geometry("400x100")
 
     label = tk.Label(examp_add, text='''An example folder had been created in your Desktop \n
@@ -111,7 +111,7 @@ Follow de User Guide instructions to procces its data.''')
     tk.Button(examp_add, text='Ok', 
               command=examp_add.destroy).pack(pady=10)
 
-    examp_add.mainloop()
+    #examp_add.mainloop()
     return
 
 def select_dir(to_enable):
@@ -180,7 +180,7 @@ def isomer_count():
 def GUI_end():
     '''Final window/widget to politely finish the programe'''
     byby = tk.Tk()
-    byby.wm_title("DP4+")
+    byby.wm_title("MESSI")
     byby.geometry("150x100")
 
     tk.Label(byby, text='Process completed \nPress Exit.').place(x=20,y=20)
@@ -188,6 +188,18 @@ def GUI_end():
               command=exit).place(x=60,y=60)
 
     byby.mainloop()
+    return
+
+def create_exe(): 
+    '''Creates a direc acces executable file in the user desktop'''
+    desktop = os.path.join(os.path.join(os.environ['USERPROFILE']), 'Desktop')
+    dir_acc = os.path.join(desktop,'messi.py')      
+
+    with open (dir_acc, 'w') as file: 
+        file.write('# -*- coding: utf-8 -*-\n\n')
+        file.write('import os, shutil\n\n')
+        file.write('exe = shutil.which("messi")\n\n')
+        file.write('os.system(exe)\n\n')
 
 
 def change_directory(s):
@@ -265,18 +277,6 @@ def label_check(wtl, isom):
     except:
         return wtl
 
-#def isomer_count():
-#    'Employs de filename to diferenciate and count the number of isomers'
-#    lista= glob.glob('*.log') + glob.glob('*.out')
-#    isomer_list =[]
-#    for e in lista:
-#        if e[0:3] not in isomer_list:
-#            isomer_list.append(e[0:3])
-#        else:
-#            continue
-#    isomer_list.sort() ##RG
-#    isomer_list.sort(key=lambda s: len(s)) #RG    
-#    return len(isomer_list), isomer_list
 
 def get_energy(file):
     'Extract SCF energies of every Gaussian 09 output'
@@ -461,12 +461,15 @@ def escalado_CyH(Unscaled_shift, exp):
     UnsC_d = np.array(UnsC_d).reshape(-1,1)
     regresion = linear_model.LinearRegression()
 
-    regresion.fit(shifts, UnsC_d) 
-   
-    m = regresion.coef_       
-    b = regresion.intercept_    
-
-    Scaled_shift = (UnsC_d - b) / m
+    if len(shifts) == 1:
+        Scaled_shift = shifts
+    else:
+        regresion.fit(shifts, UnsC_d) 
+       
+        m = regresion.coef_       
+        b = regresion.intercept_    
+    
+        Scaled_shift = (UnsC_d - b) / m
     Scaled_shift = pd.DataFrame(Scaled_shift)
 
     shifts = pd.DataFrame(shifts)
@@ -620,7 +623,6 @@ def modify_report(report, problems):
     for i in range(b):
         row = problems.iloc[i,1]+2
         col = ABC_DARIO[problems.iloc[i,0] + 1]
-        print(f'{col}{row}')
         ws[f'{col}{row}'].fill = PatternFill(start_color = 'B0C4DE', end_color = 'B0C4DE', fill_type = "solid")
         
     wb.save('MESSI_Results.xlsx')
